#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.12.0
visibility:           public
id:                   tamarin-prover-export-1.12.0-DyAUpzSpBS93s5f6XDKuJr
key:                  tamarin-prover-export-1.12.0-DyAUpzSpBS93s5f6XDKuJr
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  41aa978ecc59576e067d09cbd87ed5cc
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation ProVerifHeader
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.12.0-DyAUpzSpBS93s5f6XDKuJr
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.12.0-AacNH0Ss9HyCxc25RmVfSM
    tamarin-prover-term-1.12.0-Jk9ZodHq0oW2pGKZzJ1APL
    tamarin-prover-theory-1.12.0-8IjfU3EMXu573FfEEl4kX
    tamarin-prover-utils-1.12.0-8Rnrm8ePpu5HcNV8mKq83w text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

